netapp_ontap.models.security_saml_def_metadata_certificate API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_saml_def_metadata_certificate`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecuritySamlDefMetadataCertificateSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecuritySamlDefMetadataCertificate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ca: str GET POST`

    Server certificate issuing certificate authority (CA). This cannot be used with the server certificate common name.

  `common_name: str GET POST`

    Server certificate common name. This cannot be used with the certificate authority (CA) or serial_number.

    Example: cluster1

  `serial_number: str GET POST`

    Server certificate serial number. This cannot be used with the server certificate common name.

    Example: 1506B24A94F566BA